@@ -28,8 +28,8 @@ Chart::Chart(QWidget* parent) :
 	
 	setSizePolicy(QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);
 	
-	memoryInfos = NULL;
-	freeMemoryLabel = NULL;
+    memoryInfos = nullptr;
+    mFreeMemoryLabel = nullptr;
 }
 
 
@@ -38,13 +38,12 @@ void Chart::setMemoryInfos(t_memsize* memoryInfos) {
 }
 
 void Chart::setFreeMemoryLabel(QLabel* freeMemoryLabel) {
-	this->freeMemoryLabel = freeMemoryLabel;
+    this->mFreeMemoryLabel = freeMemoryLabel;
 }
 
 
 /* Graphical Memory Display */
 bool Chart::drawChart(t_memsize total, const QList<t_memsize>& used, const QList<QColor>& colors, const QList<QString>& texts) {
-	
 	QPainter paint(this);
 
 	QPen pen(QColor(0, 0, 0));
@@ -54,11 +53,13 @@ bool Chart::drawChart(t_memsize total, const QList<t_memsize>& used, const QList
 		paint.fillRect(1, 1, width() - 2, height() - 2, QBrush(QColor(128, 128, 128)));
 		paint.setPen(pen);
 		paint.drawRect(rect());
-		freeMemoryLabel->setText(i18n("Not available."));
+		setAccessibleDescription(i18n("Not available."));
+        mFreeMemoryLabel->setText(i18n("Not available."));
 
 		return false;
 	}
 
+	QStringList accessibleDescription;
 	int startline = height()-2;
 	
 	int percent, localheight;
@@ -90,6 +91,7 @@ bool Chart::drawChart(t_memsize total, const QList<t_memsize>& used, const QList
 
 			if (localheight >= SPACING) {
 				paint.drawText(0, startline-localheight, width(), localheight, Qt::AlignCenter | Qt::TextWordWrap, QStringLiteral("%1 %2%").arg(text).arg(percent));
+				accessibleDescription.append(QStringLiteral("%1 %2%").arg(text).arg(percent));
 			}
 		}
 
@@ -101,9 +103,9 @@ bool Chart::drawChart(t_memsize total, const QList<t_memsize>& used, const QList
 	QRect r = rect();
 	qDrawShadePanel(&paint, r.x(), r.y(), r.width(), r.height(), palette(), true, 1);
 
-	freeMemoryLabel->setText(i18n("%1 free", formattedUnit(last_used)));
+    mFreeMemoryLabel->setText(i18n("%1 free", formattedUnit(last_used)));
 
-	
+	setAccessibleDescription(accessibleDescription.join('\n'));
 	return true;
 }
 
@@ -127,13 +129,13 @@ ChartWidget::ChartWidget(const QString& title, const QString& hint, Chart* chart
 	chart->setToolTip(hint);
 	mainLayout->addWidget(chart);
 	
-	freeMemoryLabel = new QLabel(QLatin1String(""), this);
-	freeMemoryLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
-	freeMemoryLabel->setAlignment(Qt::AlignHCenter);
-	freeMemoryLabel->setToolTip(hint);
-	mainLayout->addWidget(freeMemoryLabel);
+    mFreeMemoryLabel = new QLabel(QLatin1String(""), this);
+    mFreeMemoryLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
+    mFreeMemoryLabel->setAlignment(Qt::AlignHCenter);
+    mFreeMemoryLabel->setToolTip(hint);
+    mainLayout->addWidget(mFreeMemoryLabel);
 
-	chart->setFreeMemoryLabel(freeMemoryLabel);
+    chart->setFreeMemoryLabel(mFreeMemoryLabel);
 }
 
 void ChartWidget::setMemoryInfos(t_memsize* memoryInfos) {
